# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.assistant import (
    V2GetChatsResponse,
    V2GetURLMetadataResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV2:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_chat(self, client: AlphaxivCat) -> None:
        v2_stream = client.assistant.v2.chat(
            files=[
                {
                    "content_type": "contentType",
                    "url": "https://example.com",
                }
            ],
            llm_chat_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
            paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_message_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selection_page_range=[0, 0],
            thinking=True,
            web_search="off",
        )
        v2_stream.response.close()

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_chat_with_all_params(self, client: AlphaxivCat) -> None:
        v2_stream = client.assistant.v2.chat(
            files=[
                {
                    "content_type": "contentType",
                    "url": "https://example.com",
                }
            ],
            llm_chat_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
            paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_message_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selection_page_range=[0, 0],
            thinking=True,
            web_search="off",
            assistant_variant="homepage",
            folder_add_papers=True,
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            model="gemini-2.5-flash",
        )
        v2_stream.response.close()

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_chat(self, client: AlphaxivCat) -> None:
        response = client.assistant.v2.with_raw_response.chat(
            files=[
                {
                    "content_type": "contentType",
                    "url": "https://example.com",
                }
            ],
            llm_chat_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
            paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_message_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selection_page_range=[0, 0],
            thinking=True,
            web_search="off",
        )

        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        stream = response.parse()
        stream.close()

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_chat(self, client: AlphaxivCat) -> None:
        with client.assistant.v2.with_streaming_response.chat(
            files=[
                {
                    "content_type": "contentType",
                    "url": "https://example.com",
                }
            ],
            llm_chat_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
            paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_message_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selection_page_range=[0, 0],
            thinking=True,
            web_search="off",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            stream = response.parse()
            stream.close()

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete_chat(self, client: AlphaxivCat) -> None:
        v2 = client.assistant.v2.delete_chat(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete_chat(self, client: AlphaxivCat) -> None:
        response = client.assistant.v2.with_raw_response.delete_chat(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete_chat(self, client: AlphaxivCat) -> None:
        with client.assistant.v2.with_streaming_response.delete_chat(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_delete_chat(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `llm_chat` but received ''"):
            client.assistant.v2.with_raw_response.delete_chat(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_edit_chat(self, client: AlphaxivCat) -> None:
        v2 = client.assistant.v2.edit_chat(
            llm_chat="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            title="title",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_edit_chat(self, client: AlphaxivCat) -> None:
        response = client.assistant.v2.with_raw_response.edit_chat(
            llm_chat="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            title="title",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_edit_chat(self, client: AlphaxivCat) -> None:
        with client.assistant.v2.with_streaming_response.edit_chat(
            llm_chat="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            title="title",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_path_params_edit_chat(self, client: AlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `llm_chat` but received ''"):
            client.assistant.v2.with_raw_response.edit_chat(
                llm_chat="",
                title="title",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_chats(self, client: AlphaxivCat) -> None:
        v2 = client.assistant.v2.get_chats()
        assert_matches_type(V2GetChatsResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_chats_with_all_params(self, client: AlphaxivCat) -> None:
        v2 = client.assistant.v2.get_chats(
            folder="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            variant="homepage",
        )
        assert_matches_type(V2GetChatsResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_chats(self, client: AlphaxivCat) -> None:
        response = client.assistant.v2.with_raw_response.get_chats()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert_matches_type(V2GetChatsResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_chats(self, client: AlphaxivCat) -> None:
        with client.assistant.v2.with_streaming_response.get_chats() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert_matches_type(V2GetChatsResponse, v2, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_url_metadata(self, client: AlphaxivCat) -> None:
        v2 = client.assistant.v2.get_url_metadata(
            url="https://example.com",
        )
        assert_matches_type(V2GetURLMetadataResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_url_metadata(self, client: AlphaxivCat) -> None:
        response = client.assistant.v2.with_raw_response.get_url_metadata(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = response.parse()
        assert_matches_type(V2GetURLMetadataResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_url_metadata(self, client: AlphaxivCat) -> None:
        with client.assistant.v2.with_streaming_response.get_url_metadata(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = response.parse()
            assert_matches_type(V2GetURLMetadataResponse, v2, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncV2:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_chat(self, async_client: AsyncAlphaxivCat) -> None:
        v2_stream = await async_client.assistant.v2.chat(
            files=[
                {
                    "content_type": "contentType",
                    "url": "https://example.com",
                }
            ],
            llm_chat_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
            paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_message_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selection_page_range=[0, 0],
            thinking=True,
            web_search="off",
        )
        await v2_stream.response.aclose()

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_chat_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v2_stream = await async_client.assistant.v2.chat(
            files=[
                {
                    "content_type": "contentType",
                    "url": "https://example.com",
                }
            ],
            llm_chat_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
            paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_message_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selection_page_range=[0, 0],
            thinking=True,
            web_search="off",
            assistant_variant="homepage",
            folder_add_papers=True,
            folder_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            model="gemini-2.5-flash",
        )
        await v2_stream.response.aclose()

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_chat(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.assistant.v2.with_raw_response.chat(
            files=[
                {
                    "content_type": "contentType",
                    "url": "https://example.com",
                }
            ],
            llm_chat_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
            paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_message_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selection_page_range=[0, 0],
            thinking=True,
            web_search="off",
        )

        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        stream = await response.parse()
        await stream.close()

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_chat(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.assistant.v2.with_streaming_response.chat(
            files=[
                {
                    "content_type": "contentType",
                    "url": "https://example.com",
                }
            ],
            llm_chat_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            message="message",
            paper_version_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            parent_message_id="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            selection_page_range=[0, 0],
            thinking=True,
            web_search="off",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            stream = await response.parse()
            await stream.close()

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete_chat(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.assistant.v2.delete_chat(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete_chat(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.assistant.v2.with_raw_response.delete_chat(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete_chat(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.assistant.v2.with_streaming_response.delete_chat(
            "182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_delete_chat(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `llm_chat` but received ''"):
            await async_client.assistant.v2.with_raw_response.delete_chat(
                "",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_edit_chat(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.assistant.v2.edit_chat(
            llm_chat="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            title="title",
        )
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_edit_chat(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.assistant.v2.with_raw_response.edit_chat(
            llm_chat="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            title="title",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert v2 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_edit_chat(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.assistant.v2.with_streaming_response.edit_chat(
            llm_chat="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            title="title",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert v2 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_path_params_edit_chat(self, async_client: AsyncAlphaxivCat) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `llm_chat` but received ''"):
            await async_client.assistant.v2.with_raw_response.edit_chat(
                llm_chat="",
                title="title",
            )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_chats(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.assistant.v2.get_chats()
        assert_matches_type(V2GetChatsResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_chats_with_all_params(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.assistant.v2.get_chats(
            folder="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            paper_version="182bd5e5-6e1a-4fe4-a799-aa6d9a6ab26e",
            variant="homepage",
        )
        assert_matches_type(V2GetChatsResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_chats(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.assistant.v2.with_raw_response.get_chats()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert_matches_type(V2GetChatsResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_chats(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.assistant.v2.with_streaming_response.get_chats() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert_matches_type(V2GetChatsResponse, v2, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_url_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        v2 = await async_client.assistant.v2.get_url_metadata(
            url="https://example.com",
        )
        assert_matches_type(V2GetURLMetadataResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_url_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.assistant.v2.with_raw_response.get_url_metadata(
            url="https://example.com",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v2 = await response.parse()
        assert_matches_type(V2GetURLMetadataResponse, v2, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_url_metadata(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.assistant.v2.with_streaming_response.get_url_metadata(
            url="https://example.com",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v2 = await response.parse()
            assert_matches_type(V2GetURLMetadataResponse, v2, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from ..._models import BaseModel

__all__ = ["V1GetWeeklyPrivateNotesResponse", "V1GetWeeklyPrivateNotesResponseItem"]


class V1GetWeeklyPrivateNotesResponseItem(BaseModel):
    count: float

    week: str


V1GetWeeklyPrivateNotesResponse: TypeAlias = List[V1GetWeeklyPrivateNotesResponseItem]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1LookupUserByEmailResponse"]


class V1LookupUserByEmailResponse(BaseModel):
    id: str

    email: str

    institution: Optional[str] = None

    real_name: str = FieldInfo(alias="realName")

    role: Literal["user", "reviewer", "admin", "bot"]

    updated_at: str = FieldInfo(alias="updatedAt")

    username: str

    verified: bool



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.retool.v1_get_cumulative_users_response import V1GetCumulativeUsersResponse
from ...types.retool.v1_get_total_user_count_response import V1GetTotalUserCountResponse
from ...types.retool.v1_get_total_paper_count_response import V1GetTotalPaperCountResponse
from ...types.retool.v1_get_daily_new_accounts_response import V1GetDailyNewAccountsResponse
from ...types.retool.v1_get_daily_conversations_response import V1GetDailyConversationsResponse
from ...types.retool.v1_get_total_comment_count_response import V1GetTotalCommentCountResponse
from ...types.retool.v1_get_weekly_private_notes_response import V1GetWeeklyPrivateNotesResponse
from ...types.retool.v1_get_weekly_public_comments_response import V1GetWeeklyPublicCommentsResponse
from ...types.retool.v1_get_daily_user_chat_messages_response import V1GetDailyUserChatMessagesResponse
from ...types.retool.v1_get_total_private_notes_count_response import V1GetTotalPrivateNotesCountResponse
from ...types.retool.v1_get_weekly_message_counts_by_user_response import V1GetWeeklyMessageCountsByUserResponse

__all__ = ["V1Resource", "AsyncV1Resource"]


class V1Resource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> V1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V1ResourceWithStreamingResponse(self)

    def get_cumulative_users(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetCumulativeUsersResponse:
        """
        Get cumulative user count over time (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-cumulative-users.controller.ts`
        """
        return self._get(
            "/retool/v1/cumulative-users",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetCumulativeUsersResponse,
        )

    def get_daily_conversations(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetDailyConversationsResponse:
        """
        Get daily conversation counts by variant (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-daily-conversations.controller.ts`
        """
        return self._get(
            "/retool/v1/daily-conversations",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetDailyConversationsResponse,
        )

    def get_daily_new_accounts(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetDailyNewAccountsResponse:
        """
        Get daily new account counts (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-daily-new-accounts.controller.ts`
        """
        return self._get(
            "/retool/v1/daily-new-accounts",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetDailyNewAccountsResponse,
        )

    def get_daily_user_chat_messages(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetDailyUserChatMessagesResponse:
        """
        Get daily user chat message counts by variant (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-daily-user-chat-messages.controller.ts`
        """
        return self._get(
            "/retool/v1/daily-user-chat-messages",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetDailyUserChatMessagesResponse,
        )

    def get_total_comment_count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetTotalCommentCountResponse:
        """
        Get total count of all comments

        Source file:
        `api-server/src/controllers/retool/v1/get-total-comment-count.controller.ts`
        """
        return self._get(
            "/retool/v1/total-comment-count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=float,
        )

    def get_total_paper_count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetTotalPaperCountResponse:
        """
        Get total count of public, non-blocked papers

        Source file:
        `api-server/src/controllers/retool/v1/get-total-paper-count.controller.ts`
        """
        return self._get(
            "/retool/v1/total-paper-count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=float,
        )

    def get_total_private_notes_count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetTotalPrivateNotesCountResponse:
        """
        Get total count of private notes (comments with tag=personal)

        Source file:
        `api-server/src/controllers/retool/v1/get-total-private-notes-count.controller.ts`
        """
        return self._get(
            "/retool/v1/total-private-notes-count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=float,
        )

    def get_total_user_count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetTotalUserCountResponse:
        """
        Get total count of non-deleted users

        Source file:
        `api-server/src/controllers/retool/v1/get-total-user-count.controller.ts`
        """
        return self._get(
            "/retool/v1/total-user-count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=float,
        )

    def get_weekly_message_counts_by_user(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetWeeklyMessageCountsByUserResponse:
        """
        Get assistant input message counts per user for the last week, sorted by count
        descending

        Source file:
        `api-server/src/controllers/retool/v1/get-weekly-message-counts-by-user.controller.ts`
        """
        return self._get(
            "/retool/v1/weekly-message-counts-by-user",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetWeeklyMessageCountsByUserResponse,
        )

    def get_weekly_private_notes(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetWeeklyPrivateNotesResponse:
        """
        Get weekly private note counts (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-weekly-private-notes.controller.ts`
        """
        return self._get(
            "/retool/v1/weekly-private-notes",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetWeeklyPrivateNotesResponse,
        )

    def get_weekly_public_comments(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetWeeklyPublicCommentsResponse:
        """
        Get weekly public comment counts (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-weekly-public-comments.controller.ts`
        """
        return self._get(
            "/retool/v1/weekly-public-comments",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetWeeklyPublicCommentsResponse,
        )


class AsyncV1Resource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncV1ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV1ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV1ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV1ResourceWithStreamingResponse(self)

    async def get_cumulative_users(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetCumulativeUsersResponse:
        """
        Get cumulative user count over time (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-cumulative-users.controller.ts`
        """
        return await self._get(
            "/retool/v1/cumulative-users",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetCumulativeUsersResponse,
        )

    async def get_daily_conversations(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetDailyConversationsResponse:
        """
        Get daily conversation counts by variant (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-daily-conversations.controller.ts`
        """
        return await self._get(
            "/retool/v1/daily-conversations",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetDailyConversationsResponse,
        )

    async def get_daily_new_accounts(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetDailyNewAccountsResponse:
        """
        Get daily new account counts (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-daily-new-accounts.controller.ts`
        """
        return await self._get(
            "/retool/v1/daily-new-accounts",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetDailyNewAccountsResponse,
        )

    async def get_daily_user_chat_messages(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetDailyUserChatMessagesResponse:
        """
        Get daily user chat message counts by variant (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-daily-user-chat-messages.controller.ts`
        """
        return await self._get(
            "/retool/v1/daily-user-chat-messages",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetDailyUserChatMessagesResponse,
        )

    async def get_total_comment_count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetTotalCommentCountResponse:
        """
        Get total count of all comments

        Source file:
        `api-server/src/controllers/retool/v1/get-total-comment-count.controller.ts`
        """
        return await self._get(
            "/retool/v1/total-comment-count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=float,
        )

    async def get_total_paper_count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetTotalPaperCountResponse:
        """
        Get total count of public, non-blocked papers

        Source file:
        `api-server/src/controllers/retool/v1/get-total-paper-count.controller.ts`
        """
        return await self._get(
            "/retool/v1/total-paper-count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=float,
        )

    async def get_total_private_notes_count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetTotalPrivateNotesCountResponse:
        """
        Get total count of private notes (comments with tag=personal)

        Source file:
        `api-server/src/controllers/retool/v1/get-total-private-notes-count.controller.ts`
        """
        return await self._get(
            "/retool/v1/total-private-notes-count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=float,
        )

    async def get_total_user_count(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetTotalUserCountResponse:
        """
        Get total count of non-deleted users

        Source file:
        `api-server/src/controllers/retool/v1/get-total-user-count.controller.ts`
        """
        return await self._get(
            "/retool/v1/total-user-count",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=float,
        )

    async def get_weekly_message_counts_by_user(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetWeeklyMessageCountsByUserResponse:
        """
        Get assistant input message counts per user for the last week, sorted by count
        descending

        Source file:
        `api-server/src/controllers/retool/v1/get-weekly-message-counts-by-user.controller.ts`
        """
        return await self._get(
            "/retool/v1/weekly-message-counts-by-user",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetWeeklyMessageCountsByUserResponse,
        )

    async def get_weekly_private_notes(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetWeeklyPrivateNotesResponse:
        """
        Get weekly private note counts (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-weekly-private-notes.controller.ts`
        """
        return await self._get(
            "/retool/v1/weekly-private-notes",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetWeeklyPrivateNotesResponse,
        )

    async def get_weekly_public_comments(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V1GetWeeklyPublicCommentsResponse:
        """
        Get weekly public comment counts (all time)

        Source file:
        `api-server/src/controllers/retool/v1/get-weekly-public-comments.controller.ts`
        """
        return await self._get(
            "/retool/v1/weekly-public-comments",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V1GetWeeklyPublicCommentsResponse,
        )


class V1ResourceWithRawResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.get_cumulative_users = to_raw_response_wrapper(
            v1.get_cumulative_users,
        )
        self.get_daily_conversations = to_raw_response_wrapper(
            v1.get_daily_conversations,
        )
        self.get_daily_new_accounts = to_raw_response_wrapper(
            v1.get_daily_new_accounts,
        )
        self.get_daily_user_chat_messages = to_raw_response_wrapper(
            v1.get_daily_user_chat_messages,
        )
        self.get_total_comment_count = to_raw_response_wrapper(
            v1.get_total_comment_count,
        )
        self.get_total_paper_count = to_raw_response_wrapper(
            v1.get_total_paper_count,
        )
        self.get_total_private_notes_count = to_raw_response_wrapper(
            v1.get_total_private_notes_count,
        )
        self.get_total_user_count = to_raw_response_wrapper(
            v1.get_total_user_count,
        )
        self.get_weekly_message_counts_by_user = to_raw_response_wrapper(
            v1.get_weekly_message_counts_by_user,
        )
        self.get_weekly_private_notes = to_raw_response_wrapper(
            v1.get_weekly_private_notes,
        )
        self.get_weekly_public_comments = to_raw_response_wrapper(
            v1.get_weekly_public_comments,
        )


class AsyncV1ResourceWithRawResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.get_cumulative_users = async_to_raw_response_wrapper(
            v1.get_cumulative_users,
        )
        self.get_daily_conversations = async_to_raw_response_wrapper(
            v1.get_daily_conversations,
        )
        self.get_daily_new_accounts = async_to_raw_response_wrapper(
            v1.get_daily_new_accounts,
        )
        self.get_daily_user_chat_messages = async_to_raw_response_wrapper(
            v1.get_daily_user_chat_messages,
        )
        self.get_total_comment_count = async_to_raw_response_wrapper(
            v1.get_total_comment_count,
        )
        self.get_total_paper_count = async_to_raw_response_wrapper(
            v1.get_total_paper_count,
        )
        self.get_total_private_notes_count = async_to_raw_response_wrapper(
            v1.get_total_private_notes_count,
        )
        self.get_total_user_count = async_to_raw_response_wrapper(
            v1.get_total_user_count,
        )
        self.get_weekly_message_counts_by_user = async_to_raw_response_wrapper(
            v1.get_weekly_message_counts_by_user,
        )
        self.get_weekly_private_notes = async_to_raw_response_wrapper(
            v1.get_weekly_private_notes,
        )
        self.get_weekly_public_comments = async_to_raw_response_wrapper(
            v1.get_weekly_public_comments,
        )


class V1ResourceWithStreamingResponse:
    def __init__(self, v1: V1Resource) -> None:
        self._v1 = v1

        self.get_cumulative_users = to_streamed_response_wrapper(
            v1.get_cumulative_users,
        )
        self.get_daily_conversations = to_streamed_response_wrapper(
            v1.get_daily_conversations,
        )
        self.get_daily_new_accounts = to_streamed_response_wrapper(
            v1.get_daily_new_accounts,
        )
        self.get_daily_user_chat_messages = to_streamed_response_wrapper(
            v1.get_daily_user_chat_messages,
        )
        self.get_total_comment_count = to_streamed_response_wrapper(
            v1.get_total_comment_count,
        )
        self.get_total_paper_count = to_streamed_response_wrapper(
            v1.get_total_paper_count,
        )
        self.get_total_private_notes_count = to_streamed_response_wrapper(
            v1.get_total_private_notes_count,
        )
        self.get_total_user_count = to_streamed_response_wrapper(
            v1.get_total_user_count,
        )
        self.get_weekly_message_counts_by_user = to_streamed_response_wrapper(
            v1.get_weekly_message_counts_by_user,
        )
        self.get_weekly_private_notes = to_streamed_response_wrapper(
            v1.get_weekly_private_notes,
        )
        self.get_weekly_public_comments = to_streamed_response_wrapper(
            v1.get_weekly_public_comments,
        )


class AsyncV1ResourceWithStreamingResponse:
    def __init__(self, v1: AsyncV1Resource) -> None:
        self._v1 = v1

        self.get_cumulative_users = async_to_streamed_response_wrapper(
            v1.get_cumulative_users,
        )
        self.get_daily_conversations = async_to_streamed_response_wrapper(
            v1.get_daily_conversations,
        )
        self.get_daily_new_accounts = async_to_streamed_response_wrapper(
            v1.get_daily_new_accounts,
        )
        self.get_daily_user_chat_messages = async_to_streamed_response_wrapper(
            v1.get_daily_user_chat_messages,
        )
        self.get_total_comment_count = async_to_streamed_response_wrapper(
            v1.get_total_comment_count,
        )
        self.get_total_paper_count = async_to_streamed_response_wrapper(
            v1.get_total_paper_count,
        )
        self.get_total_private_notes_count = async_to_streamed_response_wrapper(
            v1.get_total_private_notes_count,
        )
        self.get_total_user_count = async_to_streamed_response_wrapper(
            v1.get_total_user_count,
        )
        self.get_weekly_message_counts_by_user = async_to_streamed_response_wrapper(
            v1.get_weekly_message_counts_by_user,
        )
        self.get_weekly_private_notes = async_to_streamed_response_wrapper(
            v1.get_weekly_private_notes,
        )
        self.get_weekly_public_comments = async_to_streamed_response_wrapper(
            v1.get_weekly_public_comments,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["V3RetrieveAllParams"]


class V3RetrieveAllParams(TypedDict, total=False):
    limit: str

    skip: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional
from typing_extensions import Literal

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = [
    "V2CommentResponse",
    "Annotation",
    "AnnotationAnchorPosition",
    "AnnotationFocusPosition",
    "AnnotationHighlightRect",
    "AnnotationHighlightRectRect",
    "Author",
    "AuthorAvatar",
    "Endorsement",
    "Response",
    "ResponseAnnotation",
    "ResponseAnnotationAnchorPosition",
    "ResponseAnnotationFocusPosition",
    "ResponseAnnotationHighlightRect",
    "ResponseAnnotationHighlightRectRect",
    "ResponseAuthor",
    "ResponseAuthorAvatar",
    "ResponseEndorsement",
]


class AnnotationAnchorPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class AnnotationFocusPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class AnnotationHighlightRectRect(BaseModel):
    x1: float

    x2: float

    y1: float

    y2: float


class AnnotationHighlightRect(BaseModel):
    page_index: float = FieldInfo(alias="pageIndex")

    rects: List[AnnotationHighlightRectRect]


class Annotation(BaseModel):
    anchor_position: AnnotationAnchorPosition = FieldInfo(alias="anchorPosition")

    focus_position: AnnotationFocusPosition = FieldInfo(alias="focusPosition")

    highlight_rects: List[AnnotationHighlightRect] = FieldInfo(alias="highlightRects")

    selected_text: str = FieldInfo(alias="selectedText")

    type: Literal["highlight"]

    color: Optional[str] = None


class AuthorAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class Author(BaseModel):
    id: str

    avatar: Optional[List[AuthorAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class Endorsement(BaseModel):
    id: str

    name: str


class ResponseAnnotationAnchorPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class ResponseAnnotationFocusPosition(BaseModel):
    offset: float

    page_index: float = FieldInfo(alias="pageIndex")

    span_index: float = FieldInfo(alias="spanIndex")


class ResponseAnnotationHighlightRectRect(BaseModel):
    x1: float

    x2: float

    y1: float

    y2: float


class ResponseAnnotationHighlightRect(BaseModel):
    page_index: float = FieldInfo(alias="pageIndex")

    rects: List[ResponseAnnotationHighlightRectRect]


class ResponseAnnotation(BaseModel):
    anchor_position: ResponseAnnotationAnchorPosition = FieldInfo(alias="anchorPosition")

    focus_position: ResponseAnnotationFocusPosition = FieldInfo(alias="focusPosition")

    highlight_rects: List[ResponseAnnotationHighlightRect] = FieldInfo(alias="highlightRects")

    selected_text: str = FieldInfo(alias="selectedText")

    type: Literal["highlight"]

    color: Optional[str] = None


class ResponseAuthorAvatar(BaseModel):
    type: Literal["full_size", "thumbnail"]

    url: str


class ResponseAuthor(BaseModel):
    id: str

    avatar: Optional[List[ResponseAuthorAvatar]] = None

    bluesky_username: Optional[str] = FieldInfo(alias="blueskyUsername", default=None)

    github_username: Optional[str] = FieldInfo(alias="githubUsername", default=None)

    google_scholar_id: Optional[str] = FieldInfo(alias="googleScholarId", default=None)

    institution: Optional[str] = None

    linkedin_username: Optional[str] = FieldInfo(alias="linkedinUsername", default=None)

    orcid_id: Optional[str] = FieldInfo(alias="orcidId", default=None)

    public_email: Optional[str] = FieldInfo(alias="publicEmail", default=None)

    real_name: str = FieldInfo(alias="realName")

    reputation: float

    role: Literal["user", "reviewer", "admin", "bot"]

    username: str

    verified: bool

    weekly_reputation: float = FieldInfo(alias="weeklyReputation")

    x_username: Optional[str] = FieldInfo(alias="xUsername", default=None)


class ResponseEndorsement(BaseModel):
    id: str

    name: str


class Response(BaseModel):
    id: str

    annotation: Optional[ResponseAnnotation] = None

    author: ResponseAuthor

    author_responded: bool = FieldInfo(alias="authorResponded")

    body: Optional[str] = None

    date: str

    endorsements: List[ResponseEndorsement]

    has_downvoted: bool = FieldInfo(alias="hasDownvoted")

    has_flagged: bool = FieldInfo(alias="hasFlagged")

    has_upvoted: bool = FieldInfo(alias="hasUpvoted")

    is_author: bool = FieldInfo(alias="isAuthor")

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    paper_title: str = FieldInfo(alias="paperTitle")

    paper_version_id: str = FieldInfo(alias="paperVersionId")

    tag: str

    title: Optional[str] = None

    universal_id: str = FieldInfo(alias="universalId")

    upvotes: float

    was_edited: bool = FieldInfo(alias="wasEdited")


class V2CommentResponse(BaseModel):
    id: str

    annotation: Optional[Annotation] = None

    author: Author

    author_responded: bool = FieldInfo(alias="authorResponded")

    body: Optional[str] = None

    date: str

    endorsements: List[Endorsement]

    has_downvoted: bool = FieldInfo(alias="hasDownvoted")

    has_flagged: bool = FieldInfo(alias="hasFlagged")

    has_upvoted: bool = FieldInfo(alias="hasUpvoted")

    is_author: bool = FieldInfo(alias="isAuthor")

    paper_group_id: str = FieldInfo(alias="paperGroupId")

    paper_title: str = FieldInfo(alias="paperTitle")

    paper_version_id: str = FieldInfo(alias="paperVersionId")

    responses: List[Response]

    tag: str

    title: Optional[str] = None

    universal_id: str = FieldInfo(alias="universalId")

    upvotes: float

    was_edited: bool = FieldInfo(alias="wasEdited")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Iterable
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["EmailProcessCommentUpdateParams", "CustomContent", "CustomContentEvent"]


class EmailProcessCommentUpdateParams(TypedDict, total=False):
    user_id: Required[Annotated[str, PropertyInfo(alias="userId")]]

    custom_content: Annotated[CustomContent, PropertyInfo(alias="customContent")]


class CustomContentEvent(TypedDict, total=False):
    date: Required[str]

    description: Required[str]

    link: Required[str]

    title: Required[str]

    end_time_raw: Annotated[str, PropertyInfo(alias="endTimeRaw")]

    start_time_raw: Annotated[str, PropertyInfo(alias="startTimeRaw")]


class CustomContent(TypedDict, total=False):
    events: Iterable[CustomContentEvent]

    intro_text: Annotated[str, PropertyInfo(alias="introText")]

    subject: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from ..._types import SequenceNotStr
from ..._utils import PropertyInfo

__all__ = ["V3ProcessCountriesParams"]


class V3ProcessCountriesParams(TypedDict, total=False):
    universal_paper_ids: Required[Annotated[SequenceNotStr[str], PropertyInfo(alias="universalPaperIds")]]
    """Array of universal paper IDs (versionless)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3KickoffXMentionsSyncParams"]


class V3KickoffXMentionsSyncParams(TypedDict, total=False):
    dry_run: Annotated[bool, PropertyInfo(alias="dryRun")]
    """If true, only logs papers without queuing"""

    limit: int
    """Number of hot papers to sync (default: 500)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["PaperViewCountIngestEventParams"]


class PaperViewCountIngestEventParams(TypedDict, total=False):
    paper_id: Required[Annotated[str, PropertyInfo(alias="paperId")]]
    """Paper ID to track view for"""

    created_at: Annotated[str, PropertyInfo(alias="createdAt")]
    """Optional timestamp for the view event"""

    user_id: Annotated[Optional[str], PropertyInfo(alias="userId")]
    """Optional user ID who viewed the paper"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Literal

import httpx

from .shared import (
    SharedResource,
    AsyncSharedResource,
    SharedResourceWithRawResponse,
    AsyncSharedResourceWithRawResponse,
    SharedResourceWithStreamingResponse,
    AsyncSharedResourceWithStreamingResponse,
)
from ...._types import Body, Omit, Query, Headers, NoneType, NotGiven, SequenceNotStr, omit, not_given
from ...._utils import maybe_transform, async_maybe_transform
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.folders import (
    v3_create_params,
    v3_add_papers_params,
    v3_move_papers_params,
    v3_update_name_params,
    v3_remove_papers_params,
    v3_update_parent_params,
    v3_toggle_sharing_params,
)
from ....types.folders.v3_list_response import V3ListResponse
from ....types.folders.v3_create_response import V3CreateResponse
from ....types.folders.v3_add_papers_response import V3AddPapersResponse
from ....types.folders.v3_move_papers_response import V3MovePapersResponse
from ....types.folders.v3_toggle_sharing_response import V3ToggleSharingResponse

__all__ = ["V3Resource", "AsyncV3Resource"]


class V3Resource(SyncAPIResource):
    @cached_property
    def shared(self) -> SharedResource:
        return SharedResource(self._client)

    @cached_property
    def with_raw_response(self) -> V3ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return V3ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> V3ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return V3ResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        folder_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V3CreateResponse:
        """
        Create a new folder for the current user

        Source file: `api-server/src/controllers/folders/v3/create-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/folders/v3",
            body=maybe_transform({"folder_name": folder_name}, v3_create_params.V3CreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V3CreateResponse,
        )

    def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V3ListResponse:
        """
        Get all folders for the current user

        Source file: `api-server/src/controllers/folders/v3/get-folders.controller.ts`
        """
        return self._get(
            "/folders/v3",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V3ListResponse,
        )

    def delete(
        self,
        folder_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete a folder

        Source file: `api-server/src/controllers/folders/v3/delete-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/folders/v3/{folder_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def add_papers(
        self,
        folder_id: str,
        *,
        paper_group_ids: SequenceNotStr[str] | Omit = omit,
        universal_ids: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V3AddPapersResponse:
        """
        Add papers to a folder (without removing from other folders)

        Source file:
        `api-server/src/controllers/folders/v3/add-papers-to-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        return self._post(
            f"/folders/v3/{folder_id}/add-papers",
            body=maybe_transform(
                {
                    "paper_group_ids": paper_group_ids,
                    "universal_ids": universal_ids,
                },
                v3_add_papers_params.V3AddPapersParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V3AddPapersResponse,
        )

    def move_papers(
        self,
        folder_id: str,
        *,
        paper_group_ids: SequenceNotStr[str],
        from_folder_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V3MovePapersResponse:
        """
        Move papers from source folder to destination folder

        Source file:
        `api-server/src/controllers/folders/v3/move-papers-to-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        return self._post(
            f"/folders/v3/{folder_id}/move-papers",
            body=maybe_transform(
                {
                    "paper_group_ids": paper_group_ids,
                    "from_folder_id": from_folder_id,
                },
                v3_move_papers_params.V3MovePapersParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V3MovePapersResponse,
        )

    def remove_papers(
        self,
        folder_id: str,
        *,
        paper_group_ids: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Remove papers from a specific folder

        Source file: `api-server/src/controllers/folders/v3/remove-papers.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._post(
            f"/folders/v3/{folder_id}/remove-papers",
            body=maybe_transform({"paper_group_ids": paper_group_ids}, v3_remove_papers_params.V3RemovePapersParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def toggle_sharing(
        self,
        folder_id: str,
        *,
        sharing_status: Literal["not_shared", "shared"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V3ToggleSharingResponse:
        """
        Toggle whether a folder and all its descendant folders are shared or not

        Source file:
        `api-server/src/controllers/folders/v3/toggle-folder-sharing.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        return self._patch(
            f"/folders/v3/{folder_id}/sharing",
            body=maybe_transform({"sharing_status": sharing_status}, v3_toggle_sharing_params.V3ToggleSharingParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V3ToggleSharingResponse,
        )

    def update_name(
        self,
        folder_id: str,
        *,
        name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Rename a folder

        Source file:
        `api-server/src/controllers/folders/v3/update-folder-name.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._patch(
            f"/folders/v3/{folder_id}",
            body=maybe_transform({"name": name}, v3_update_name_params.V3UpdateNameParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def update_parent(
        self,
        folder_id: str,
        *,
        parent_id: Optional[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update a folder's parent (for nesting)

        Source file:
        `api-server/src/controllers/folders/v3/update-folder-parent.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._patch(
            f"/folders/v3/{folder_id}/parent",
            body=maybe_transform({"parent_id": parent_id}, v3_update_parent_params.V3UpdateParentParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class AsyncV3Resource(AsyncAPIResource):
    @cached_property
    def shared(self) -> AsyncSharedResource:
        return AsyncSharedResource(self._client)

    @cached_property
    def with_raw_response(self) -> AsyncV3ResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncV3ResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncV3ResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncV3ResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        folder_name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V3CreateResponse:
        """
        Create a new folder for the current user

        Source file: `api-server/src/controllers/folders/v3/create-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/folders/v3",
            body=await async_maybe_transform({"folder_name": folder_name}, v3_create_params.V3CreateParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V3CreateResponse,
        )

    async def list(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V3ListResponse:
        """
        Get all folders for the current user

        Source file: `api-server/src/controllers/folders/v3/get-folders.controller.ts`
        """
        return await self._get(
            "/folders/v3",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V3ListResponse,
        )

    async def delete(
        self,
        folder_id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Delete a folder

        Source file: `api-server/src/controllers/folders/v3/delete-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/folders/v3/{folder_id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def add_papers(
        self,
        folder_id: str,
        *,
        paper_group_ids: SequenceNotStr[str] | Omit = omit,
        universal_ids: SequenceNotStr[str] | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V3AddPapersResponse:
        """
        Add papers to a folder (without removing from other folders)

        Source file:
        `api-server/src/controllers/folders/v3/add-papers-to-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        return await self._post(
            f"/folders/v3/{folder_id}/add-papers",
            body=await async_maybe_transform(
                {
                    "paper_group_ids": paper_group_ids,
                    "universal_ids": universal_ids,
                },
                v3_add_papers_params.V3AddPapersParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V3AddPapersResponse,
        )

    async def move_papers(
        self,
        folder_id: str,
        *,
        paper_group_ids: SequenceNotStr[str],
        from_folder_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V3MovePapersResponse:
        """
        Move papers from source folder to destination folder

        Source file:
        `api-server/src/controllers/folders/v3/move-papers-to-folder.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        return await self._post(
            f"/folders/v3/{folder_id}/move-papers",
            body=await async_maybe_transform(
                {
                    "paper_group_ids": paper_group_ids,
                    "from_folder_id": from_folder_id,
                },
                v3_move_papers_params.V3MovePapersParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V3MovePapersResponse,
        )

    async def remove_papers(
        self,
        folder_id: str,
        *,
        paper_group_ids: SequenceNotStr[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Remove papers from a specific folder

        Source file: `api-server/src/controllers/folders/v3/remove-papers.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._post(
            f"/folders/v3/{folder_id}/remove-papers",
            body=await async_maybe_transform(
                {"paper_group_ids": paper_group_ids}, v3_remove_papers_params.V3RemovePapersParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def toggle_sharing(
        self,
        folder_id: str,
        *,
        sharing_status: Literal["not_shared", "shared"],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> V3ToggleSharingResponse:
        """
        Toggle whether a folder and all its descendant folders are shared or not

        Source file:
        `api-server/src/controllers/folders/v3/toggle-folder-sharing.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        return await self._patch(
            f"/folders/v3/{folder_id}/sharing",
            body=await async_maybe_transform(
                {"sharing_status": sharing_status}, v3_toggle_sharing_params.V3ToggleSharingParams
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=V3ToggleSharingResponse,
        )

    async def update_name(
        self,
        folder_id: str,
        *,
        name: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Rename a folder

        Source file:
        `api-server/src/controllers/folders/v3/update-folder-name.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._patch(
            f"/folders/v3/{folder_id}",
            body=await async_maybe_transform({"name": name}, v3_update_name_params.V3UpdateNameParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def update_parent(
        self,
        folder_id: str,
        *,
        parent_id: Optional[str],
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> None:
        """
        Update a folder's parent (for nesting)

        Source file:
        `api-server/src/controllers/folders/v3/update-folder-parent.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not folder_id:
            raise ValueError(f"Expected a non-empty value for `folder_id` but received {folder_id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._patch(
            f"/folders/v3/{folder_id}/parent",
            body=await async_maybe_transform({"parent_id": parent_id}, v3_update_parent_params.V3UpdateParentParams),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )


class V3ResourceWithRawResponse:
    def __init__(self, v3: V3Resource) -> None:
        self._v3 = v3

        self.create = to_raw_response_wrapper(
            v3.create,
        )
        self.list = to_raw_response_wrapper(
            v3.list,
        )
        self.delete = to_raw_response_wrapper(
            v3.delete,
        )
        self.add_papers = to_raw_response_wrapper(
            v3.add_papers,
        )
        self.move_papers = to_raw_response_wrapper(
            v3.move_papers,
        )
        self.remove_papers = to_raw_response_wrapper(
            v3.remove_papers,
        )
        self.toggle_sharing = to_raw_response_wrapper(
            v3.toggle_sharing,
        )
        self.update_name = to_raw_response_wrapper(
            v3.update_name,
        )
        self.update_parent = to_raw_response_wrapper(
            v3.update_parent,
        )

    @cached_property
    def shared(self) -> SharedResourceWithRawResponse:
        return SharedResourceWithRawResponse(self._v3.shared)


class AsyncV3ResourceWithRawResponse:
    def __init__(self, v3: AsyncV3Resource) -> None:
        self._v3 = v3

        self.create = async_to_raw_response_wrapper(
            v3.create,
        )
        self.list = async_to_raw_response_wrapper(
            v3.list,
        )
        self.delete = async_to_raw_response_wrapper(
            v3.delete,
        )
        self.add_papers = async_to_raw_response_wrapper(
            v3.add_papers,
        )
        self.move_papers = async_to_raw_response_wrapper(
            v3.move_papers,
        )
        self.remove_papers = async_to_raw_response_wrapper(
            v3.remove_papers,
        )
        self.toggle_sharing = async_to_raw_response_wrapper(
            v3.toggle_sharing,
        )
        self.update_name = async_to_raw_response_wrapper(
            v3.update_name,
        )
        self.update_parent = async_to_raw_response_wrapper(
            v3.update_parent,
        )

    @cached_property
    def shared(self) -> AsyncSharedResourceWithRawResponse:
        return AsyncSharedResourceWithRawResponse(self._v3.shared)


class V3ResourceWithStreamingResponse:
    def __init__(self, v3: V3Resource) -> None:
        self._v3 = v3

        self.create = to_streamed_response_wrapper(
            v3.create,
        )
        self.list = to_streamed_response_wrapper(
            v3.list,
        )
        self.delete = to_streamed_response_wrapper(
            v3.delete,
        )
        self.add_papers = to_streamed_response_wrapper(
            v3.add_papers,
        )
        self.move_papers = to_streamed_response_wrapper(
            v3.move_papers,
        )
        self.remove_papers = to_streamed_response_wrapper(
            v3.remove_papers,
        )
        self.toggle_sharing = to_streamed_response_wrapper(
            v3.toggle_sharing,
        )
        self.update_name = to_streamed_response_wrapper(
            v3.update_name,
        )
        self.update_parent = to_streamed_response_wrapper(
            v3.update_parent,
        )

    @cached_property
    def shared(self) -> SharedResourceWithStreamingResponse:
        return SharedResourceWithStreamingResponse(self._v3.shared)


class AsyncV3ResourceWithStreamingResponse:
    def __init__(self, v3: AsyncV3Resource) -> None:
        self._v3 = v3

        self.create = async_to_streamed_response_wrapper(
            v3.create,
        )
        self.list = async_to_streamed_response_wrapper(
            v3.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            v3.delete,
        )
        self.add_papers = async_to_streamed_response_wrapper(
            v3.add_papers,
        )
        self.move_papers = async_to_streamed_response_wrapper(
            v3.move_papers,
        )
        self.remove_papers = async_to_streamed_response_wrapper(
            v3.remove_papers,
        )
        self.toggle_sharing = async_to_streamed_response_wrapper(
            v3.toggle_sharing,
        )
        self.update_name = async_to_streamed_response_wrapper(
            v3.update_name,
        )
        self.update_parent = async_to_streamed_response_wrapper(
            v3.update_parent,
        )

    @cached_property
    def shared(self) -> AsyncSharedResourceWithStreamingResponse:
        return AsyncSharedResourceWithStreamingResponse(self._v3.shared)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .v3_search_params import V3SearchParams as V3SearchParams
from .v3_search_response import V3SearchResponse as V3SearchResponse
from .v3_get_activity_params import V3GetActivityParams as V3GetActivityParams
from .v3_get_activity_response import V3GetActivityResponse as V3GetActivityResponse
from .v3_update_profile_params import V3UpdateProfileParams as V3UpdateProfileParams
from .v3_get_followers_response import V3GetFollowersResponse as V3GetFollowersResponse
from .v3_upload_avatar_response import V3UploadAvatarResponse as V3UploadAvatarResponse
from .v3_update_profile_response import V3UpdateProfileResponse as V3UpdateProfileResponse
from .v3_get_leaderboard_response import V3GetLeaderboardResponse as V3GetLeaderboardResponse
from .v3_get_claimed_papers_params import V3GetClaimedPapersParams as V3GetClaimedPapersParams
from .v3_get_current_user_response import V3GetCurrentUserResponse as V3GetCurrentUserResponse
from .v3_get_user_by_uuid_response import V3GetUserByUuidResponse as V3GetUserByUuidResponse
from .v3_get_viewed_history_params import V3GetViewedHistoryParams as V3GetViewedHistoryParams
from .v3_update_preferences_params import V3UpdatePreferencesParams as V3UpdatePreferencesParams
from .v3_autocomplete_profile_params import V3AutocompleteProfileParams as V3AutocompleteProfileParams
from .v3_get_claimed_papers_response import V3GetClaimedPapersResponse as V3GetClaimedPapersResponse
from .v3_get_viewed_history_response import V3GetViewedHistoryResponse as V3GetViewedHistoryResponse
from .v3_toggle_follow_user_response import V3ToggleFollowUserResponse as V3ToggleFollowUserResponse
from .v3_update_preferences_response import V3UpdatePreferencesResponse as V3UpdatePreferencesResponse
from .v3_autocomplete_profile_response import V3AutocompleteProfileResponse as V3AutocompleteProfileResponse
from .v3_get_featured_activity_response import V3GetFeaturedActivityResponse as V3GetFeaturedActivityResponse
from .v3_process_notification_email_response import (
    V3ProcessNotificationEmailResponse as V3ProcessNotificationEmailResponse,
)
from .preference_get_folders_preferences_response import (
    PreferenceGetFoldersPreferencesResponse as PreferenceGetFoldersPreferencesResponse,
)



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v3 import (
    V3Resource,
    AsyncV3Resource,
    V3ResourceWithRawResponse,
    AsyncV3ResourceWithRawResponse,
    V3ResourceWithStreamingResponse,
    AsyncV3ResourceWithStreamingResponse,
)
from .shared import (
    SharedResource,
    AsyncSharedResource,
    SharedResourceWithRawResponse,
    AsyncSharedResourceWithRawResponse,
    SharedResourceWithStreamingResponse,
    AsyncSharedResourceWithStreamingResponse,
)

__all__ = [
    "SharedResource",
    "AsyncSharedResource",
    "SharedResourceWithRawResponse",
    "AsyncSharedResourceWithRawResponse",
    "SharedResourceWithStreamingResponse",
    "AsyncSharedResourceWithStreamingResponse",
    "V3Resource",
    "AsyncV3Resource",
    "V3ResourceWithRawResponse",
    "AsyncV3ResourceWithRawResponse",
    "V3ResourceWithStreamingResponse",
    "AsyncV3ResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from pydantic import Field as FieldInfo

from ..._models import BaseModel

__all__ = ["V1VerifyEmailResponse"]


class V1VerifyEmailResponse(BaseModel):
    google_scholar_id: str = FieldInfo(alias="googleScholarId")



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional

import httpx

from ..types import research_create_project_params
from .._types import Body, Omit, Query, Headers, NotGiven, SequenceNotStr, omit, not_given
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options

__all__ = ["ResearchResource", "AsyncResearchResource"]


class ResearchResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> ResearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return ResearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> ResearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return ResearchResourceWithStreamingResponse(self)

    def create_project(
        self,
        *,
        name: str,
        folder: Optional[research_create_project_params.Folder] | Omit = omit,
        initial_papers: SequenceNotStr[str] | Omit = omit,
        parent_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        Create a research project

        Source file:
        `api-server/src/controllers/research/v1/create-project.controller.ts`

        Args:
          folder: Prefill the project with a set of research papers.

          initial_papers: Add these papers to the group on init

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/research/v1",
            body=maybe_transform(
                {
                    "name": name,
                    "folder": folder,
                    "initial_papers": initial_papers,
                    "parent_id": parent_id,
                },
                research_create_project_params.ResearchCreateProjectParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class AsyncResearchResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncResearchResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncResearchResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncResearchResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncResearchResourceWithStreamingResponse(self)

    async def create_project(
        self,
        *,
        name: str,
        folder: Optional[research_create_project_params.Folder] | Omit = omit,
        initial_papers: SequenceNotStr[str] | Omit = omit,
        parent_id: str | Omit = omit,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> str:
        """
        Create a research project

        Source file:
        `api-server/src/controllers/research/v1/create-project.controller.ts`

        Args:
          folder: Prefill the project with a set of research papers.

          initial_papers: Add these papers to the group on init

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/research/v1",
            body=await async_maybe_transform(
                {
                    "name": name,
                    "folder": folder,
                    "initial_papers": initial_papers,
                    "parent_id": parent_id,
                },
                research_create_project_params.ResearchCreateProjectParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class ResearchResourceWithRawResponse:
    def __init__(self, research: ResearchResource) -> None:
        self._research = research

        self.create_project = to_raw_response_wrapper(
            research.create_project,
        )


class AsyncResearchResourceWithRawResponse:
    def __init__(self, research: AsyncResearchResource) -> None:
        self._research = research

        self.create_project = async_to_raw_response_wrapper(
            research.create_project,
        )


class ResearchResourceWithStreamingResponse:
    def __init__(self, research: ResearchResource) -> None:
        self._research = research

        self.create_project = to_streamed_response_wrapper(
            research.create_project,
        )


class AsyncResearchResourceWithStreamingResponse:
    def __init__(self, research: AsyncResearchResource) -> None:
        self._research = research

        self.create_project = async_to_streamed_response_wrapper(
            research.create_project,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal, Required, Annotated, TypedDict

from ..._utils import PropertyInfo

__all__ = ["V3ToggleSharingParams"]


class V3ToggleSharingParams(TypedDict, total=False):
    sharing_status: Required[Annotated[Literal["not_shared", "shared"], PropertyInfo(alias="sharingStatus")]]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from alphaxiv_cat import AlphaxivCat, AsyncAlphaxivCat
from alphaxiv_cat.types.google_scholar import (
    V1SyncResponse,
    V1ResyncResponse,
    V1ConnectResponse,
    V1GetReportResponse,
    V1GetStatusResponse,
    V1VerifyEmailResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestV1:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_connect(self, client: AlphaxivCat) -> None:
        v1 = client.google_scholar.v1.connect(
            google_scholar_id="x",
        )
        assert_matches_type(V1ConnectResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_connect(self, client: AlphaxivCat) -> None:
        response = client.google_scholar.v1.with_raw_response.connect(
            google_scholar_id="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1ConnectResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_connect(self, client: AlphaxivCat) -> None:
        with client.google_scholar.v1.with_streaming_response.connect(
            google_scholar_id="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1ConnectResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_delete_connection(self, client: AlphaxivCat) -> None:
        v1 = client.google_scholar.v1.delete_connection()
        assert v1 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_delete_connection(self, client: AlphaxivCat) -> None:
        response = client.google_scholar.v1.with_raw_response.delete_connection()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert v1 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_delete_connection(self, client: AlphaxivCat) -> None:
        with client.google_scholar.v1.with_streaming_response.delete_connection() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_report(self, client: AlphaxivCat) -> None:
        v1 = client.google_scholar.v1.get_report()
        assert_matches_type(V1GetReportResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_report(self, client: AlphaxivCat) -> None:
        response = client.google_scholar.v1.with_raw_response.get_report()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetReportResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_report(self, client: AlphaxivCat) -> None:
        with client.google_scholar.v1.with_streaming_response.get_report() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetReportResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_get_status(self, client: AlphaxivCat) -> None:
        v1 = client.google_scholar.v1.get_status()
        assert_matches_type(V1GetStatusResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_get_status(self, client: AlphaxivCat) -> None:
        response = client.google_scholar.v1.with_raw_response.get_status()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1GetStatusResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_get_status(self, client: AlphaxivCat) -> None:
        with client.google_scholar.v1.with_streaming_response.get_status() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1GetStatusResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_resync(self, client: AlphaxivCat) -> None:
        v1 = client.google_scholar.v1.resync(
            "all",
        )
        assert_matches_type(V1ResyncResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_resync(self, client: AlphaxivCat) -> None:
        response = client.google_scholar.v1.with_raw_response.resync(
            "all",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1ResyncResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_resync(self, client: AlphaxivCat) -> None:
        with client.google_scholar.v1.with_streaming_response.resync(
            "all",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1ResyncResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_set_email(self, client: AlphaxivCat) -> None:
        v1 = client.google_scholar.v1.set_email(
            local_part="localPart",
            verify_account_email=True,
        )
        assert v1 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_set_email(self, client: AlphaxivCat) -> None:
        response = client.google_scholar.v1.with_raw_response.set_email(
            local_part="localPart",
            verify_account_email=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert v1 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_set_email(self, client: AlphaxivCat) -> None:
        with client.google_scholar.v1.with_streaming_response.set_email(
            local_part="localPart",
            verify_account_email=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_sync(self, client: AlphaxivCat) -> None:
        v1 = client.google_scholar.v1.sync()
        assert_matches_type(V1SyncResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_sync(self, client: AlphaxivCat) -> None:
        response = client.google_scholar.v1.with_raw_response.sync()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1SyncResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_sync(self, client: AlphaxivCat) -> None:
        with client.google_scholar.v1.with_streaming_response.sync() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1SyncResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_method_verify_email(self, client: AlphaxivCat) -> None:
        v1 = client.google_scholar.v1.verify_email(
            code="xxxxxx",
        )
        assert_matches_type(V1VerifyEmailResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_raw_response_verify_email(self, client: AlphaxivCat) -> None:
        response = client.google_scholar.v1.with_raw_response.verify_email(
            code="xxxxxx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = response.parse()
        assert_matches_type(V1VerifyEmailResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    def test_streaming_response_verify_email(self, client: AlphaxivCat) -> None:
        with client.google_scholar.v1.with_streaming_response.verify_email(
            code="xxxxxx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = response.parse()
            assert_matches_type(V1VerifyEmailResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True


class TestAsyncV1:
    parametrize = pytest.mark.parametrize(
        "async_client", [False, True, {"http_client": "aiohttp"}], indirect=True, ids=["loose", "strict", "aiohttp"]
    )

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_connect(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.google_scholar.v1.connect(
            google_scholar_id="x",
        )
        assert_matches_type(V1ConnectResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_connect(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.google_scholar.v1.with_raw_response.connect(
            google_scholar_id="x",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1ConnectResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_connect(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.google_scholar.v1.with_streaming_response.connect(
            google_scholar_id="x",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1ConnectResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_delete_connection(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.google_scholar.v1.delete_connection()
        assert v1 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_delete_connection(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.google_scholar.v1.with_raw_response.delete_connection()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert v1 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_delete_connection(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.google_scholar.v1.with_streaming_response.delete_connection() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_report(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.google_scholar.v1.get_report()
        assert_matches_type(V1GetReportResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_report(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.google_scholar.v1.with_raw_response.get_report()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetReportResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_report(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.google_scholar.v1.with_streaming_response.get_report() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetReportResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_get_status(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.google_scholar.v1.get_status()
        assert_matches_type(V1GetStatusResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_get_status(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.google_scholar.v1.with_raw_response.get_status()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1GetStatusResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_get_status(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.google_scholar.v1.with_streaming_response.get_status() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1GetStatusResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_resync(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.google_scholar.v1.resync(
            "all",
        )
        assert_matches_type(V1ResyncResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_resync(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.google_scholar.v1.with_raw_response.resync(
            "all",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1ResyncResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_resync(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.google_scholar.v1.with_streaming_response.resync(
            "all",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1ResyncResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_set_email(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.google_scholar.v1.set_email(
            local_part="localPart",
            verify_account_email=True,
        )
        assert v1 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_set_email(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.google_scholar.v1.with_raw_response.set_email(
            local_part="localPart",
            verify_account_email=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert v1 is None

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_set_email(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.google_scholar.v1.with_streaming_response.set_email(
            local_part="localPart",
            verify_account_email=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert v1 is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_sync(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.google_scholar.v1.sync()
        assert_matches_type(V1SyncResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_sync(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.google_scholar.v1.with_raw_response.sync()

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1SyncResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_sync(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.google_scholar.v1.with_streaming_response.sync() as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1SyncResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_method_verify_email(self, async_client: AsyncAlphaxivCat) -> None:
        v1 = await async_client.google_scholar.v1.verify_email(
            code="xxxxxx",
        )
        assert_matches_type(V1VerifyEmailResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_raw_response_verify_email(self, async_client: AsyncAlphaxivCat) -> None:
        response = await async_client.google_scholar.v1.with_raw_response.verify_email(
            code="xxxxxx",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        v1 = await response.parse()
        assert_matches_type(V1VerifyEmailResponse, v1, path=["response"])

    @pytest.mark.skip(reason="Mock server tests are disabled")
    @parametrize
    async def test_streaming_response_verify_email(self, async_client: AsyncAlphaxivCat) -> None:
        async with async_client.google_scholar.v1.with_streaming_response.verify_email(
            code="xxxxxx",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            v1 = await response.parse()
            assert_matches_type(V1VerifyEmailResponse, v1, path=["response"])

        assert cast(Any, response.is_closed) is True



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import httpx

from ..._types import Body, Query, Headers, NotGiven, not_given
from ..._compat import cached_property
from ..._resource import SyncAPIResource, AsyncAPIResource
from ..._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ..._base_client import make_request_options
from ...types.papers.kickoff_daily_github_star_update_response import KickoffDailyGitHubStarUpdateResponse
from ...types.papers.kickoff_daily_github_star_kickoff_daily_github_stars_response import (
    KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse,
)

__all__ = ["KickoffDailyGitHubStarsResource", "AsyncKickoffDailyGitHubStarsResource"]


class KickoffDailyGitHubStarsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> KickoffDailyGitHubStarsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return KickoffDailyGitHubStarsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> KickoffDailyGitHubStarsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return KickoffDailyGitHubStarsResourceWithStreamingResponse(self)

    def update(
        self,
        max: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> KickoffDailyGitHubStarUpdateResponse:
        """
        Kickoff background job to update daily GitHub stars with max limit

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-daily-github-stars-max.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not max:
            raise ValueError(f"Expected a non-empty value for `max` but received {max!r}")
        return self._post(
            f"/v2/papers/kickoff-daily-github-stars/{max}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KickoffDailyGitHubStarUpdateResponse,
        )

    def kickoff_daily_github_stars(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse:
        """
        Kickoff background job to update daily GitHub stars

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-daily-github-stars.controller.ts`
        """
        return self._post(
            "/v2/papers/kickoff-daily-github-stars",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse,
        )


class AsyncKickoffDailyGitHubStarsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncKickoffDailyGitHubStarsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncKickoffDailyGitHubStarsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncKickoffDailyGitHubStarsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncKickoffDailyGitHubStarsResourceWithStreamingResponse(self)

    async def update(
        self,
        max: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> KickoffDailyGitHubStarUpdateResponse:
        """
        Kickoff background job to update daily GitHub stars with max limit

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-daily-github-stars-max.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not max:
            raise ValueError(f"Expected a non-empty value for `max` but received {max!r}")
        return await self._post(
            f"/v2/papers/kickoff-daily-github-stars/{max}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KickoffDailyGitHubStarUpdateResponse,
        )

    async def kickoff_daily_github_stars(
        self,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse:
        """
        Kickoff background job to update daily GitHub stars

        Source file:
        `api-server/src/controllers/v2/papers/kickoff-daily-github-stars.controller.ts`
        """
        return await self._post(
            "/v2/papers/kickoff-daily-github-stars",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=KickoffDailyGitHubStarKickoffDailyGitHubStarsResponse,
        )


class KickoffDailyGitHubStarsResourceWithRawResponse:
    def __init__(self, kickoff_daily_github_stars: KickoffDailyGitHubStarsResource) -> None:
        self._kickoff_daily_github_stars = kickoff_daily_github_stars

        self.update = to_raw_response_wrapper(
            kickoff_daily_github_stars.update,
        )
        self.kickoff_daily_github_stars = to_raw_response_wrapper(
            kickoff_daily_github_stars.kickoff_daily_github_stars,
        )


class AsyncKickoffDailyGitHubStarsResourceWithRawResponse:
    def __init__(self, kickoff_daily_github_stars: AsyncKickoffDailyGitHubStarsResource) -> None:
        self._kickoff_daily_github_stars = kickoff_daily_github_stars

        self.update = async_to_raw_response_wrapper(
            kickoff_daily_github_stars.update,
        )
        self.kickoff_daily_github_stars = async_to_raw_response_wrapper(
            kickoff_daily_github_stars.kickoff_daily_github_stars,
        )


class KickoffDailyGitHubStarsResourceWithStreamingResponse:
    def __init__(self, kickoff_daily_github_stars: KickoffDailyGitHubStarsResource) -> None:
        self._kickoff_daily_github_stars = kickoff_daily_github_stars

        self.update = to_streamed_response_wrapper(
            kickoff_daily_github_stars.update,
        )
        self.kickoff_daily_github_stars = to_streamed_response_wrapper(
            kickoff_daily_github_stars.kickoff_daily_github_stars,
        )


class AsyncKickoffDailyGitHubStarsResourceWithStreamingResponse:
    def __init__(self, kickoff_daily_github_stars: AsyncKickoffDailyGitHubStarsResource) -> None:
        self._kickoff_daily_github_stars = kickoff_daily_github_stars

        self.update = async_to_streamed_response_wrapper(
            kickoff_daily_github_stars.update,
        )
        self.kickoff_daily_github_stars = async_to_streamed_response_wrapper(
            kickoff_daily_github_stars.kickoff_daily_github_stars,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import Optional

from ..._models import BaseModel

__all__ = ["V2RetrieveByIDResponse"]


class V2RetrieveByIDResponse(BaseModel):
    id: str

    image: Optional[str] = None

    name: str

    slug: str



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .._models import BaseModel

__all__ = ["EmailKickoffCommentUpdateResponse", "Data"]


class Data(BaseModel):
    message: str


class EmailKickoffCommentUpdateResponse(BaseModel):
    data: Data



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .v2 import (
    V2Resource,
    AsyncV2Resource,
    V2ResourceWithRawResponse,
    AsyncV2ResourceWithRawResponse,
    V2ResourceWithStreamingResponse,
    AsyncV2ResourceWithStreamingResponse,
)
from .search import (
    SearchResource,
    AsyncSearchResource,
    SearchResourceWithRawResponse,
    AsyncSearchResourceWithRawResponse,
    SearchResourceWithStreamingResponse,
    AsyncSearchResourceWithStreamingResponse,
)

__all__ = [
    "V2Resource",
    "AsyncV2Resource",
    "V2ResourceWithRawResponse",
    "AsyncV2ResourceWithRawResponse",
    "V2ResourceWithStreamingResponse",
    "AsyncV2ResourceWithStreamingResponse",
    "SearchResource",
    "AsyncSearchResource",
    "SearchResourceWithRawResponse",
    "AsyncSearchResourceWithRawResponse",
    "SearchResourceWithStreamingResponse",
    "AsyncSearchResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Literal

import httpx

from ...._types import Body, Query, Headers, NotGiven, not_given
from ...._compat import cached_property
from ...._resource import SyncAPIResource, AsyncAPIResource
from ...._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from ...._base_client import make_request_options
from ....types.papers.v3.overview_retrieve_response import OverviewRetrieveResponse
from ....types.papers.v3.overview_retrieve_status_response import OverviewRetrieveStatusResponse

__all__ = ["OverviewResource", "AsyncOverviewResource"]


class OverviewResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> OverviewResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return OverviewResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> OverviewResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return OverviewResourceWithStreamingResponse(self)

    def retrieve(
        self,
        language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "en",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ],
        *,
        paper_version: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OverviewRetrieveResponse:
        """Retrieve paper version overview for given language.

        Does not create it if it
        doesn't exist

        Source file: `api-server/src/controllers/papers/v3/get-overviews.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_version:
            raise ValueError(f"Expected a non-empty value for `paper_version` but received {paper_version!r}")
        if not language:
            raise ValueError(f"Expected a non-empty value for `language` but received {language!r}")
        return self._get(
            f"/papers/v3/{paper_version}/overview/{language}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OverviewRetrieveResponse,
        )

    def retrieve_status(
        self,
        paper_version: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OverviewRetrieveStatusResponse:
        """
        Retrieve paper version status for overview generation and translations

        Source file:
        `api-server/src/controllers/papers/v3/get-overviews-status.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_version:
            raise ValueError(f"Expected a non-empty value for `paper_version` but received {paper_version!r}")
        return self._get(
            f"/papers/v3/{paper_version}/overview/status",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OverviewRetrieveStatusResponse,
        )


class AsyncOverviewResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncOverviewResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#accessing-raw-response-data-eg-headers
        """
        return AsyncOverviewResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncOverviewResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/AlphaxivCat/alphaxiv_cat-python#with_streaming_response
        """
        return AsyncOverviewResourceWithStreamingResponse(self)

    async def retrieve(
        self,
        language: Literal[
            "am",
            "ar",
            "az",
            "bg",
            "bn",
            "ca",
            "cs",
            "da",
            "de",
            "el",
            "en",
            "es",
            "et",
            "fa",
            "fi",
            "fr",
            "gu",
            "ha",
            "he",
            "hi",
            "hr",
            "hu",
            "id",
            "it",
            "ja",
            "ka",
            "kn",
            "ko",
            "lt",
            "lv",
            "ml",
            "mr",
            "ms",
            "my",
            "ne",
            "nl",
            "no",
            "pa",
            "pl",
            "pt",
            "ro",
            "ru",
            "si",
            "sk",
            "sl",
            "sr",
            "sv",
            "sw",
            "ta",
            "te",
            "th",
            "tl",
            "tr",
            "uk",
            "ur",
            "uz",
            "vi",
            "yo",
            "zh",
        ],
        *,
        paper_version: str,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OverviewRetrieveResponse:
        """Retrieve paper version overview for given language.

        Does not create it if it
        doesn't exist

        Source file: `api-server/src/controllers/papers/v3/get-overviews.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_version:
            raise ValueError(f"Expected a non-empty value for `paper_version` but received {paper_version!r}")
        if not language:
            raise ValueError(f"Expected a non-empty value for `language` but received {language!r}")
        return await self._get(
            f"/papers/v3/{paper_version}/overview/{language}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OverviewRetrieveResponse,
        )

    async def retrieve_status(
        self,
        paper_version: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = not_given,
    ) -> OverviewRetrieveStatusResponse:
        """
        Retrieve paper version status for overview generation and translations

        Source file:
        `api-server/src/controllers/papers/v3/get-overviews-status.controller.ts`

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not paper_version:
            raise ValueError(f"Expected a non-empty value for `paper_version` but received {paper_version!r}")
        return await self._get(
            f"/papers/v3/{paper_version}/overview/status",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=OverviewRetrieveStatusResponse,
        )


class OverviewResourceWithRawResponse:
    def __init__(self, overview: OverviewResource) -> None:
        self._overview = overview

        self.retrieve = to_raw_response_wrapper(
            overview.retrieve,
        )
        self.retrieve_status = to_raw_response_wrapper(
            overview.retrieve_status,
        )


class AsyncOverviewResourceWithRawResponse:
    def __init__(self, overview: AsyncOverviewResource) -> None:
        self._overview = overview

        self.retrieve = async_to_raw_response_wrapper(
            overview.retrieve,
        )
        self.retrieve_status = async_to_raw_response_wrapper(
            overview.retrieve_status,
        )


class OverviewResourceWithStreamingResponse:
    def __init__(self, overview: OverviewResource) -> None:
        self._overview = overview

        self.retrieve = to_streamed_response_wrapper(
            overview.retrieve,
        )
        self.retrieve_status = to_streamed_response_wrapper(
            overview.retrieve_status,
        )


class AsyncOverviewResourceWithStreamingResponse:
    def __init__(self, overview: AsyncOverviewResource) -> None:
        self._overview = overview

        self.retrieve = async_to_streamed_response_wrapper(
            overview.retrieve,
        )
        self.retrieve_status = async_to_streamed_response_wrapper(
            overview.retrieve_status,
        )
